@@ -1,5 +1,5 @@
 /*
- * dvdspanky - a video to DVD MPEG conversion frontend for transcode
+ * dvdspanky - a video to DVD MPEG conversion front-end for transcode
  * Copyright (C) 2007  Jeffrey Grembecki
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,7 +34,7 @@
 #include "vstr.h"
 #include "config.h"
 
-static char gp_title[] = "dvdspanky 1.0.1 - (C) 2007 Jeffrey Grembecki\n\n";
+static char gp_title[] = "dvdspanky 1.0.2 - (C) 2007 Jeffrey Grembecki\n\n";
 static char gp_licence[] =
 "This program is free software; you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
@@ -64,10 +64,10 @@ static char gp_help[] =
 "-b, --border           automatic black border [off]\n"
 "-B, --clip             clips edges to fit aspect [off]\n"
 "-c, --channels=CHANS   number of audio channels [auto] {1 - 5}\n"
-"-f, --filters=FILTERS  specify aditional transcode filters [none]\n"
+"-f, --filters=FILTERS  specify additional transcode filters [none]\n"
 "-g, --gain=GAIN        multiply volume by GAIN [off/1.0]\n"
 "-G, --gamma=GAMMA      set gamma, < 1.0 is brighter, > is darker [1.0]\n"
-"-F, --frameadjust      interlace video for framerate conversion [off] *\n"
+"-F, --frameadjust      interlace video for frame-rate conversion [off] *\n"
 "-h, --help             this help text\n"
 "-H, --hcrop=PIXELS     as above [off]\n"
 "-i, --input=FILE       input file\n"
@@ -551,9 +551,9 @@ int encode(video_t *p_in, video_t *p_out, int options, const char *p_filters)
 		}
 
 		print(ML_INFO, "\n");
-		vs_print(p_final, "%s.m2v");
+		vs_print(p_final, "%s.m2v", p_out->p_filename);
 		unlink(p_final->s);
-		vs_print(p_final, "%s.ac3");
+		vs_print(p_final, "%s.ac3", p_out->p_filename);
 		unlink(p_final->s);
 	}
 
@@ -692,10 +692,10 @@ int cb_transcode(const char *p_string, void *p_options)
 		for(i = 1; i < 6; i++)
 			p_buffer[p_vector[i * 2 + 1]] = 0;
 		if(p_video->frames)
-			fprintf(stderr,"  %7.2f fps, %7.2f%% complete, frame %d  \r", atof(&p_buffer[p_vector[4]]),
+			fprintf(stderr,"  %6.2f fps, %.2f%% complete, frame %d  \r", atof(&p_buffer[p_vector[4]]),
 				atof(&p_buffer[p_vector[2]]) * 100.0 / (double)p_video->frames, atoi(&p_buffer[p_vector[2]]));
 		else
-			fprintf(stderr,"  %7.2f fps, frame %09d, %d:%02d:%02d  \r", atof(&p_buffer[p_vector[4]]),
+			fprintf(stderr,"  %6.2f fps, frame %09d, %d:%02d:%02d  \r", atof(&p_buffer[p_vector[4]]),
 				atoi(&p_buffer[2]), atoi(&p_buffer[p_vector[4]]), atoi(&p_buffer[p_vector[6]]),
 				atoi(&p_buffer[p_vector[8]]));
 	}
@@ -1370,7 +1370,7 @@ int main(int argc, char **argv)
 		outvid.p_vcodec, outvid.width, outvid.height, outvid.vrate, outvid.fps);
 	print(ML_INFO, "        | %.4f aspect, %d frames, %d:%02d:%02d\n",
 		outvid.aspect, outvid.frames, outvid.hours, outvid.minutes, outvid.seconds);
-	print(ML_INFO, "        | %d:%d crop, %s\n",
+	print(ML_INFO, "        | %d(v):%d(h) crop, %s\n",
 		outvid.vcrop, outvid.hcrop, (options & SPANK_MULTI) ? "VBR" : "CBR");
 	print(ML_INFO, "  audio | %s, %d kbps, %d Hz, %d bit, %d channel\n",
 		outvid.p_acodec, outvid.arate, outvid.hz, outvid.abits, outvid.achans);
